Color

Struct Color 

pub struct Color { /* private fields */ }
This represents an RGB color, stored as it’s individual color values and it’s hexadecimal string

Implementations

Source

impl Color

pub fn rgb(r: u8, g: u8, b: u8) -> Self

Create a new Color from a red color value, a green color value and a blue color value

pub fn from_color_string(string: &str) -> Result<Self, Error>

Create a new Color from a color name. This will result in an error if the color name isn’t recognized

recognized names
  • red => (255, 0, 0)
  • green => (0, 255, 0)
  • blue => (0, 0, 255)
  • white => (255, 255, 255)
  • black => (0, 0, 0)
  • yellow => (255, 255 ,0)
  • purple => (255, 0, 255)
  • cyan => (0, 255, 255)
pub fn from_rgb_string(string: &str) -> Result<Self, Error>

Create a new Color from a string slice formatted this way : “(r,g,b)” - “()” are necessary - Each value must be seperated by a comma - Each value must be at most 255 - whitespace is irrelevant This will result in an error if the string cannot be parsed

pub fn from_hexadecimal(hexadecimal_color: &str) -> Result<Self, FromHexError>

Create a new Color from a string slice representing an hexadecimal value - The number of ‘#’ at the start of the slice is irrelevant - The slice must contain exactly 6 hexadecimal digits (ignoring ‘#’) - The casing of the hexadecimal value is irrelevant

[API note]
  • This makes use of the hex crate
pub fn red(&self) -> u8

Returns the red value of the color

pub fn green(&self) -> u8

Returns the green value of the color

pub fn blue(&self) -> u8

Returns the blue value of the color

pub fn hexadecimal_value(&self) -> String

Returns the hexadecimal value of the color

pub fn inverted(&self) -> Self

Returns the inverted variant of the color